@@ -290,7 +290,7 @@ as_distance <- function(
 #'
 #' @export
 make_train <- function(n = .7, nr = 100, seed = 1234) {
-  seed %>% gsub("[^0-9]", "", .) %>% 
+  seed %>% gsub("[^0-9]", "", .) %>%
     {if (!is_empty(.)) set.seed(seed)}
   if (n < 1) n <- round(n * nr) %>% max(1)
   ind <- seq_len(nr)
@@ -304,16 +304,16 @@ make_train <- function(n = .7, nr = 100, seed = 1234) {
 #' @details Wrapper for dplyr::mutate_at that allows custom variable name extensions
 #'
 #' @param .tbl Data frame to add transformed variables to
-#' @param .funs Function(s) to apply (e.g., funs(log))
+#' @param .funs Function(s) to apply (e.g., log)
 #' @param ... Variables to transform
 #' @param .ext Extension to add for each variable
 #' @param .vars A list of columns generated by dplyr::vars(), or a character vector of column names, or a numeric vector of column positions.
 #'
 #' @examples
-#' mutate_ext(mtcars, funs(log), mpg, cyl, .ext = "_ln")
-#' mutate_ext(mtcars, funs(log), .ext = "_ln")
-#' mutate_ext(mtcars, funs(log))
-#' mutate_ext(mtcars, funs(log), .ext = "_ln", .vars = vars(mpg, cyl))
+#' mutate_ext(mtcars, .funs = log, mpg, cyl, .ext = "_ln")
+#' mutate_ext(mtcars, .funs = log, .ext = "_ln")
+#' mutate_ext(mtcars, .funs = log)
+#' mutate_ext(mtcars, .funs = log, .ext = "_ln", .vars = vars(mpg, cyl))
 #'
 #' @export
 mutate_ext <- function(.tbl, .funs, ..., .ext = "", .vars = c()) {
@@ -417,9 +417,10 @@ weighted.sd <- function(x, wt, na.rm = TRUE) {
 #'
 #' @param dataset Data.frame
 #' @param dc Class for each variable
+#' @param dec Number of decimals to show
 #'
 #' @export
-get_summary <- function(dataset, dc = get_class(dataset)) {
+get_summary <- function(dataset, dc = get_class(dataset), dec = 3) {
   isFct <- "factor" == dc
   isNum <- dc %in% c("numeric", "integer", "Duration")
   isDate <- "date" == dc
@@ -435,7 +436,7 @@ get_summary <- function(dataset, dc = get_class(dataset)) {
       gather("variable", "values", !! cn, factor_key = TRUE) %>%
       group_by_at(.vars = "variable") %>%
       summarise_all(
-        funs(
+        list(
           n_obs = n_obs,
           n_missing = n_missing,
           n_distinct = n_distinct,
@@ -443,15 +444,15 @@ get_summary <- function(dataset, dc = get_class(dataset)) {
           median = median,
           min = min,
           max = max,
-          `25%` = p25,
-          `75%` = p75,
+          p25 = p25,
+          p75 = p75,
           sd = sd,
           se = se
         ),
         na.rm = TRUE
       ) %>%
       data.frame(check.names = FALSE, stringsAsFactors = FALSE) %>%
-      mutate_if(is.numeric, funs(round(., 3))) %>%
+      format_df(dec = dec, mark = ",") %>%
       set_colnames(c("", colnames(.)[-1])) %>%
       print(row.names = FALSE)
     cat("\n")
@@ -466,12 +467,12 @@ get_summary <- function(dataset, dc = get_class(dataset)) {
   if (sum(isDate) > 0) {
     cat("Earliest dates:\n")
     select(dataset, which(isDate)) %>%
-      summarise_all(funs(min)) %>%
+      summarise_all(min) %>%
       as.data.frame(stringsAsFactors = FALSE) %>%
       print(row.names = FALSE)
     cat("\nFinal dates:\n")
     select(dataset, which(isDate)) %>%
-      summarise_all(funs(max)) %>%
+      summarise_all(max) %>%
       as.data.frame(stringsAsFactors = FALSE) %>%
       print(row.names = FALSE)
 
@@ -484,12 +485,12 @@ get_summary <- function(dataset, dc = get_class(dataset)) {
 
     cat("Earliest time:\n")
     select(dataset, which(isPeriod)) %>%
-      summarise_all(funs(min_time)) %>%
+      summarise_all(min_time) %>%
       as.data.frame(stringsAsFactors = FALSE) %>%
       print(row.names = FALSE)
     cat("\nFinal time:\n")
     select(dataset, which(isPeriod)) %>%
-      summarise_all(funs(max_time)) %>%
+      summarise_all(max_time) %>%
       as.data.frame(stringsAsFactors = FALSE) %>%
       print(row.names = FALSE)
     cat("\n")
@@ -517,12 +518,13 @@ get_summary <- function(dataset, dc = get_class(dataset)) {
   if (sum(isLogic) > 0) {
     cat("Summarize logical variables:\n")
     select(dataset, which(isLogic)) %>%
-      summarise_all(funs(sum, mean, n_missing), na.rm = TRUE) %>%
-      mutate_if(is.numeric, funs(round(., 4))) %>%
+      summarise_all(list(x = ~ sum(., na.rm = TRUE), y = ~ mean(., na.rm = TRUE), z = ~ n_missing(.))) %>%
+      round(dec) %>%
       matrix(ncol = 3) %>%
-      data.frame(stringsAsFactors = FALSE) %>%
+      as.data.frame(stringsAsFactors = FALSE) %>%
       set_colnames(c("# TRUE", "% TRUE", "n_missing")) %>%
       set_rownames(names(dataset)[isLogic]) %>%
+      format(big.mark = ",", scientific = FALSE) %>%
       print()
     cat("\n")
   }
@@ -547,7 +549,7 @@ table2data <- function(dataset, freq = tail(colnames(dataset), 1)) {
   lapply(seq_len(nrow(dataset)), blowup) %>%
     bind_rows() %>%
     select_at(.vars = base::setdiff(colnames(dataset), freq)) %>%
-    mutate_all(funs(as.factor))
+    mutate_all(as.factor)
 }
 
 #' Generate list of levels and unique values
