@@ -98,7 +98,7 @@ output$ui_tr_reorg_levs <- renderUI({
     ),
     textInput(
       "tr_rorepl", "Replacement level name:",
-      placehold = "Provide name for missing levels",
+      placeholder = "Provide name for missing levels",
       value = NA
     )
   )
@@ -107,16 +107,19 @@ output$ui_tr_reorg_levs <- renderUI({
 output$ui_tr_log <- renderUI({
   tagList(
     HTML("<label>Transform command log:</label><br>"),
-    tags$textarea(
-      state_init("tr_log", ""),
-      id = "tr_log",
-      type = "text",
-      rows = 5,
-      autocomplete = "off",
-      autocorrect = "off",
-      autocapitalize = "off",
-      spellcheck = "false",
-      class = "form-control"
+    shinyAce::aceEditor(
+      "tr_log",
+      mode = "r",
+      theme = getOption("radiant.ace_theme", default = "tomorrow"),
+      wordWrap = TRUE,
+      value = state_init("tr_log", "") %>% fix_smart(),
+      vimKeyBinding = getOption("radiant.ace_vim.keys", default = FALSE),
+      tabSize = getOption("radiant.ace_tabSize", 2),
+      useSoftTabs = getOption("radiant.ace_useSoftTabs", TRUE),
+      showInvisibles = getOption("radiant.ace_showInvisibles", FALSE),
+      autoScrollEditorIntoView = TRUE,
+      minLines = 5,
+      maxLines = 15
     )
   )
 })
@@ -406,24 +409,35 @@ observeEvent(input$tr_change_type, {
   }
 })
 
+fix_ext <- function(ext) {
+  gsub("(^\\s+|\\s+$)", "", ext) %>%
+  gsub("\\s+", "_", .) %>%
+  gsub("[[:punct:]]", "_", .) %>%
+  gsub("\\.{2,}", ".", .) %>%
+  gsub("_{2,}", "_", .)
+}
+
 .change_type <- function(
   dataset, fun, vars = "", .ext = "",
   store_dat = "", store = TRUE
 ) {
 
+  .ext <- fix_ext(.ext)
+
   if (!store || !is.character(dataset)) {
     fun <- get(fun)
     if (is_empty(.ext)) {
-      mutate_at(dataset, .vars = vars, .funs = funs(fun))
+      mutate_at(dataset, .vars = vars, .funs = fun)
     } else {
-      mutate_at(dataset, .vars = vars, .funs = funs(fun)) %>% set_colnames(paste0(vars, .ext))
+      mutate_at(dataset, .vars = vars, .funs = fun) %>%
+        set_colnames(paste0(vars, .ext))
     }
   } else {
     if (store_dat == "") store_dat <- dataset
     if (is_empty(.ext)) {
-      paste0("## change variable type\n", store_dat, " <- mutate_at(", dataset, ", .vars = vars(", paste0(vars, collapse = ", "), "), .funs = funs(", fun, "))\n")
+      paste0("## change variable type\n", store_dat, " <- mutate_at(", dataset, ", .vars = vars(", paste0(vars, collapse = ", "), "), .funs = ", fun, ")\n")
     } else {
-      paste0("## change variable type\n", store_dat, " <- mutate_ext(", dataset, ", .vars = vars(", paste0(vars, collapse = ", "), "), .funs = funs(", fun, "), .ext = \"", .ext, "\")\n")
+      paste0("## change variable type\n", store_dat, " <- mutate_ext(", dataset, ", .vars = vars(", paste0(vars, collapse = ", "), "), .funs = ", fun, ", .ext = \"", .ext, "\")\n")
     }
   }
 }
@@ -433,19 +447,26 @@ observeEvent(input$tr_change_type, {
   store_dat = "", store = TRUE
 ) {
 
+  .ext <- fix_ext(.ext)
+
   if (!store && !is.character(dataset)) {
     fun <- get(fun)
     if (is_empty(.ext)) {
-      mutate_at(dataset, .vars = vars, .funs = funs(fun))
+      result <- try(mutate_at(dataset, .vars = vars, .funs = fun), silent = TRUE)
     } else {
-      mutate_at(dataset, .vars = vars, .funs = funs(fun)) %>% set_colnames(paste0(vars, .ext))
+      result <- try(mutate_at(dataset, .vars = vars, .funs = fun) %>% set_colnames(paste0(vars, .ext)), silent = TRUE)
+    }
+    if (inherits(result, "try-error")) {
+      paste0("\nThe transformation type you selected generated an error.\n\nThe error message was:\n\n", attr(result, "condition")$message, "\n\nPlease change the selection of variables or the transformation type and try again.")
+    } else {
+      result
     }
   } else {
     if (store_dat == "") store_dat <- dataset
     if (is_empty(.ext)) {
-      paste0("## transform variable\n", store_dat, " <- mutate_at(", dataset, ", .vars = vars(", paste0(vars, collapse = ", "), "), .funs = funs(", fun, "))\n")
+      paste0("## transform variable\n", store_dat, " <- mutate_at(", dataset, ", .vars = vars(", paste0(vars, collapse = ", "), "), .funs = ", fun, ")\n")
     } else {
-      paste0("## transform variable\n", store_dat, " <- mutate_ext(", dataset, ", .vars = vars(", paste0(vars, collapse = ", "), "), .funs = funs(", fun, "), .ext = \"", .ext, "\")\n")
+      paste0("## transform variable\n", store_dat, " <- mutate_ext(", dataset, ", .vars = vars(", paste0(vars, collapse = ", "), "), .funs = ", fun, ", .ext = \"", .ext, "\")\n")
     }
   }
 }
@@ -477,6 +498,8 @@ observeEvent(input$tr_change_type, {
 
     ## usefull if functions created in Report > R and Report > Rmd are
     ## called in Data > Transform > Create
+    ## add environment to do.call call instead?
+    ## https://stackoverflow.com/questions/26028488/do-call-specify-environment-inside-function
     attach(r_data)
     on.exit(detach(r_data))
 
@@ -577,6 +600,8 @@ observeEvent(input$tr_change_type, {
   store_dat = "", store = TRUE
 ) {
 
+  .ext <- fix_ext(.ext)
+
   if (!store && !is.character(dataset)) {
     nz <- select_at(dataset, .vars = nzvar)
     dataset <- select_at(dataset, .vars = vars)
@@ -590,7 +615,7 @@ observeEvent(input$tr_change_type, {
       set_colnames(paste0(vars, .ext))
   } else {
     if (store_dat == "") store_dat <- dataset
-    paste0("## normalize variables\n", store_dat, " <- mutate_ext(", dataset, ", .vars = vars(", paste0(vars, collapse = ", "), "), .funs = funs(normalize(.,", nzvar, ")), .ext = \"", .ext, "\")\n")
+    paste0("## normalize variables\n", store_dat, " <- mutate_ext(", dataset, ", .vars = vars(", paste0(vars, collapse = ", "), "), .funs = ~ normalize(., ", nzvar, "), .ext = \"", .ext, "\")\n")
   }
 }
 
@@ -615,6 +640,10 @@ observeEvent(input$tr_change_type, {
   dataset, vars, key, value,
   store_dat = "", store = TRUE
 ) {
+
+  key <- fix_names(key)
+  value <- fix_names(value)
+
   if (!store && !is.character(dataset)) {
     gather(dataset, !! key, !! value, !! vars, factor_key = TRUE)
   } else {
@@ -628,11 +657,14 @@ observeEvent(input$tr_change_type, {
   vars = "", store_dat = "", store = TRUE
 ) {
 
+  key <- fix_names(key)
+  value <- fix_names(value)
+
   if (!store && !is.character(dataset)) {
     if (!vars[1] == "") dataset <- select_at(dataset, .vars = vars)
     cn <- colnames(dataset)
     if (!all(key %in% cn) || !value %in% cn) return("Key or value variable is not in the dataset")
-    nr <- distinct_(dataset, .dots = base::setdiff(cn, value), .keep_all = TRUE) %>%
+    nr <- distinct_at(dataset, .vars = base::setdiff(cn, value), .keep_all = TRUE) %>%
       nrow()
     if (nr < nrow(dataset)) return("Rows are not unique. Select additional variables")
     if (length(key) > 1) {
@@ -678,18 +710,19 @@ observeEvent(input$tr_change_type, {
   .ext = "_dec", store_dat = "", store = TRUE
 ) {
 
+  .ext <- fix_ext(.ext)
+
   if (!store && !is.character(dataset)) {
     if (is.na(bins) || !is.integer(bins)) return("Please specify the (integer) number of bins to use")
-    xt <- function(x, bins, rev) radiant.data::xtile(x, bins, rev = rev)
     select_at(dataset, .vars = vars) %>%
-      mutate_all(funs(xt(., bins, rev = rev))) %>%
+      mutate_all(~ xtile(., bins, rev = rev)) %>%
       set_colnames(paste0(vars, .ext))
   } else {
     if (store_dat == "") store_dat <- dataset
     if (rev) {
-      paste0("## bin variables\n", store_dat, " <- mutate_ext(", dataset, ", .vars = vars(", paste0(vars, collapse = ", "), "), .funs = funs(xtile(., ", bins, ", rev = TRUE)), .ext = \"", .ext, "\")\n")
+      paste0("## bin variables\n", store_dat, " <- mutate_ext(", dataset, ", .vars = vars(", paste0(vars, collapse = ", "), "), .funs = ~ xtile(., ", bins, ", rev = TRUE), .ext = \"", .ext, "\")\n")
     } else {
-      paste0("## bin variables\n", store_dat, " <- mutate_ext(", dataset, ", .vars = vars(", paste0(vars, collapse = ", "), "), .funs = funs(xtile(., ", bins, ")), .ext = \"", .ext, "\")\n")
+      paste0("## bin variables\n", store_dat, " <- mutate_ext(", dataset, ", .vars = vars(", paste0(vars, collapse = ", "), "), .funs = ~ xtile(., ", bins, "), .ext = \"", .ext, "\")\n")
     }
   }
 }
@@ -700,7 +733,11 @@ observeEvent(input$tr_change_type, {
   store_dat = "", store = TRUE
 ) {
 
-  if (is_empty(name)) name <- "training"
+  if (is_empty(name)) {
+    name <- "training"
+  } else {
+    name <- fix_names(name)
+  }
   if (!store && !is.character(dataset)) {
     n <- n %>% {ifelse(. < 0 || is.na(.) || . > nr, .7, .)}
     data.frame(make_train(n, nr, seed), stringsAsFactors = FALSE) %>% setNames(name)
@@ -767,8 +804,7 @@ observeEvent(input$tr_change_type, {
     if (all(vars == "") || length(unique(vars)) == ncol(dataset)) {
       dat <- distinct(dataset)
     } else {
-      ## keeping the _ version for now because there is no distinct_at
-      dat <- distinct_(dataset, .dots = vars, .keep_all = TRUE)
+      dat <- distinct_at(dataset, .vars = vars, .keep_all = TRUE)
     }
 
     if (nrow(dat) == nrow(dataset)) {
@@ -825,13 +861,13 @@ observeEvent(input$tr_change_type, {
   store_dat = "", store = TRUE
 ) {
 
-  if (rev) filt <- paste0("!(", filt, ")")
+  if (is_empty(filt)) {
+    return(paste0("No filter found (n = ", nrow(dataset), ")"))
+  } else if (rev) {
+    filt <- paste0("!(", filt, ")")
+  }
 
   if (!store || !is.character(dataset)) {
-    if (is_empty(filt)) {
-      return(paste0("No filter found (n = ", nrow(dataset), ")"))
-    }
-
     get_data(dataset, vars = vars, filt = filt, na.rm = FALSE)
   } else {
     filt <- gsub("\"", "'", filt)
@@ -1118,11 +1154,14 @@ observeEvent(input$tr_store, {
   if (min(dim(dat)) == 0) return()
 
   ## saving to a new dataset if specified
-  df_name <- input$tr_name
+  df_name <- fix_names(input$tr_name)
+  if (input$tr_name != df_name) {
+    updateTextInput(session, inputId = "tr_name", value = df_name)
+  }
   ncmd <- ""
   if (is.null(r_data[[df_name]])) {
     r_data[[df_name]] <- .get_data_transform()
-    r_info[[paste0(df_name, "_descr")]] <- r_info[[paste0(input$df_name, "_descr")]]
+    r_info[[paste0(df_name, "_descr")]] <- r_info[[paste0(input$dataset, "_descr")]]
     if (!bindingIsActive(as.symbol(df_name), env = r_data)) {
       shiny::makeReactiveBinding(df_name, env = r_data)
     }
@@ -1146,61 +1185,61 @@ observeEvent(input$tr_store, {
   }
 
   if (input$tr_change_type == "remove_na") {
-    cmd <- .remove_na(input$dataset, vars = input$tr_vars, input$tr_name, nr_col = ncol(dat))
+    cmd <- .remove_na(input$dataset, vars = input$tr_vars, df_name, nr_col = ncol(dat))
     r_data[[df_name]] <- dat
   } else if (input$tr_change_type == "remove_dup") {
-    cmd <- .remove_dup(input$dataset, vars = input$tr_vars, input$tr_name, nr_col = ncol(dat))
+    cmd <- .remove_dup(input$dataset, vars = input$tr_vars, df_name, nr_col = ncol(dat))
     r_data[[df_name]] <- dat
   } else if (input$tr_change_type == "show_dup") {
-    cmd <- .show_dup(input$dataset, vars = input$tr_vars, input$tr_name, nr_col = ncol(dat))
+    cmd <- .show_dup(input$dataset, vars = input$tr_vars, df_name, nr_col = ncol(dat))
     r_data[[df_name]] <- dat
   } else if (input$tr_change_type == "holdout") {
-    cmd <- .holdout(input$dataset, vars = input$tr_vars, filt = input$data_filter, rev = input$tr_holdout_rev, input$tr_name)
+    cmd <- .holdout(input$dataset, vars = input$tr_vars, filt = input$data_filter, rev = input$tr_holdout_rev, df_name)
     r_data[[df_name]] <- dat
   } else if (input$tr_change_type == "tab2dat") {
-    cmd <- .tab2dat(input$dataset, input$tr_tab2dat, vars = input$tr_vars, input$tr_name)
+    cmd <- .tab2dat(input$dataset, input$tr_tab2dat, vars = input$tr_vars, df_name)
     r_data[[df_name]] <- dat
   } else if (input$tr_change_type == "gather") {
-    cmd <- .gather(input$dataset, vars = input$tr_vars, key = input$tr_gather_key, value = input$tr_gather_value, input$tr_name)
+    cmd <- .gather(input$dataset, vars = input$tr_vars, key = input$tr_gather_key, value = input$tr_gather_value, df_name)
     r_data[[df_name]] <- dat
   } else if (input$tr_change_type == "spread") {
-    cmd <- .spread(input$dataset, key = input$tr_spread_key, value = input$tr_spread_value, fill = input$tr_spread_fill, vars = input$tr_vars, input$tr_name)
+    cmd <- .spread(input$dataset, key = input$tr_spread_key, value = input$tr_spread_value, fill = input$tr_spread_fill, vars = input$tr_vars, df_name)
     r_data[[df_name]] <- dat
   } else if (input$tr_change_type == "expand") {
-    cmd <- .expand(input$dataset, vars = input$tr_vars, input$tr_name)
+    cmd <- .expand(input$dataset, vars = input$tr_vars, df_name)
     r_data[[df_name]] <- dat
   } else if (input$tr_change_type == "reorg_vars") {
-    cmd <- .reorg_vars(input$dataset, vars = input$tr_reorg_vars, input$tr_name)
+    cmd <- .reorg_vars(input$dataset, vars = input$tr_reorg_vars, df_name)
     r_data[[df_name]] <- dat
   } else if (input$tr_change_type == "type") {
-    cmd <- .change_type(input$dataset, fun = input$tr_typefunction, vars = input$tr_vars, .ext = input$tr_typename, input$tr_name)
+    cmd <- .change_type(input$dataset, fun = input$tr_typefunction, vars = input$tr_vars, .ext = input$tr_typename, df_name)
     r_data[[df_name]][, colnames(dat)] <- dat
   } else if (input$tr_change_type == "transform") {
-    cmd <- .transform(input$dataset, fun = input$tr_transfunction, vars = input$tr_vars, .ext = input$tr_ext, input$tr_name)
+    cmd <- .transform(input$dataset, fun = input$tr_transfunction, vars = input$tr_vars, .ext = input$tr_ext, df_name)
     r_data[[df_name]][, colnames(dat)] <- dat
   } else if (input$tr_change_type == "training") {
-    cmd <- .training(input$dataset, n = input$tr_training_n, nr = nrow(dat), name = input$tr_training, seed = input$tr_training_seed, input$tr_name)
+    cmd <- .training(input$dataset, n = input$tr_training_n, nr = nrow(dat), name = input$tr_training, seed = input$tr_training_seed, df_name)
     r_data[[df_name]][, colnames(dat)] <- dat
   } else if (input$tr_change_type == "normalize") {
-    cmd <- .normalize(input$dataset, vars = input$tr_vars, nzvar = input$tr_normalizer, .ext = input$tr_ext_nz, input$tr_name)
+    cmd <- .normalize(input$dataset, vars = input$tr_vars, nzvar = input$tr_normalizer, .ext = input$tr_ext_nz, df_name)
     r_data[[df_name]][, colnames(dat)] <- dat
   } else if (input$tr_change_type == "bin") {
-    cmd <- .bin(input$dataset, vars = input$tr_vars, bins = input$tr_bin_n, rev = input$tr_bin_rev, .ext = input$tr_ext_bin, input$tr_name)
+    cmd <- .bin(input$dataset, vars = input$tr_vars, bins = input$tr_bin_n, rev = input$tr_bin_rev, .ext = input$tr_ext_bin, df_name)
     r_data[[df_name]][, colnames(dat)] <- dat
   } else if (input$tr_change_type == "reorg_levs") {
-    cmd <- .reorg_levs(input$dataset, input$tr_vars[1], input$tr_reorg_levs, input$tr_rorepl, input$tr_roname, input$tr_name)
+    cmd <- .reorg_levs(input$dataset, input$tr_vars[1], input$tr_reorg_levs, input$tr_rorepl, input$tr_roname, df_name)
     r_data[[df_name]][, colnames(dat)] <- dat
   } else if (input$tr_change_type == "recode") {
-    cmd <- .recode(input$dataset, input$tr_vars[1], input$tr_recode, input$tr_rcname, input$tr_name)
+    cmd <- .recode(input$dataset, input$tr_vars[1], input$tr_recode, input$tr_rcname, df_name)
     r_data[[df_name]][, colnames(dat)] <- dat
   } else if (input$tr_change_type == "rename") {
-    cmd <- .rename(input$dataset, input$tr_vars, input$tr_rename, input$tr_name)
+    cmd <- .rename(input$dataset, input$tr_vars, input$tr_rename, df_name)
     r_data[[df_name]] %<>% rename(!!! setNames(input$tr_vars, colnames(dat)))
   } else if (input$tr_change_type == "create") {
-    cmd <- .create(input$dataset, cmd = input$tr_create, byvar = input$tr_vars, input$tr_name)
+    cmd <- .create(input$dataset, cmd = input$tr_create, byvar = input$tr_vars, df_name)
     r_data[[df_name]][, colnames(dat)] <- dat
   } else if (input$tr_change_type == "replace") {
-    cmd <- .replace(input$dataset, input$tr_vars, input$tr_replace, input$tr_name)
+    cmd <- .replace(input$dataset, input$tr_vars, input$tr_replace, df_name)
     r_data[[df_name]][, colnames(dat)] <- dat
     r_data[[df_name]][, input$tr_replace] <- list(NULL)
   } else if (input$tr_change_type == "clip") {
@@ -1209,7 +1248,8 @@ observeEvent(input$tr_store, {
   }
 
   ## update the command log
-  updateTextAreaInput(session, "tr_log", value = paste0(input$tr_log, paste0(cmd, ncmd), "\n"))
+  # updateTextAreaInput(session, "tr_log", value = paste0(input$tr_log, paste0(cmd, ncmd), "\n"))
+  shinyAce::updateAceEditor(session, "tr_log", value = paste0(input$tr_log, paste0(cmd, ncmd), "\n"))
 
   ## reset input values once the changes have been applied
   updateSelectInput(session = session, inputId = "tr_change_type", selected = "none")
@@ -1239,7 +1279,8 @@ observeEvent(input$transform_report, {
       sub("^\n", "", .) %>%
       sub("\n$", "", .)
 
-    updateTextInput(session, "tr_log", value = "")
+    # updateTextInput(session, "tr_log", value = "")
+    shinyAce::updateAceEditor(session, "tr_log", value = "")
     update_report(cmd = cmd, outputs = NULL, figs = FALSE)
   }
 })
